<?php

namespace App\Filter;

use ApiPlatform\Doctrine\Orm\Filter\AbstractFilter;
use ApiPlatform\Doctrine\Orm\Util\QueryNameGeneratorInterface;
use ApiPlatform\Metadata\Operation;
use Doctrine\ORM\QueryBuilder;
use Symfony\Component\PropertyInfo\Type;

class NotEqualIdFilter extends AbstractFilter
{
    protected function filterProperty(string $property, $value, QueryBuilder $queryBuilder, QueryNameGeneratorInterface $queryNameGenerator, string $resourceClass, ?Operation $operation = null, array $context = []): void
    {
        if ($property !== 'id') {
            return;
        }

        $alias = $queryBuilder->getRootAliases()[0];
        $queryBuilder
            ->andWhere(sprintf('%s.%s != :id', $alias, $property))
            ->setParameter('id', $value);
    }

    public function getDescription(string $resourceClass): array
    {
        return [
            'id[neq]' => [
                'property' => 'id',
                'type' => Type::BUILTIN_TYPE_INT,
                'required' => false,
                'description' => 'Filter records where id is not equal to the given value.',
            ],
        ];
    }
}